==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/my.php <==
<?php

return [
    'Names' => [
        'Arab' => 'အာရေဗျ',
        'Armn' => 'အာမေးနီးယား',
        'Beng' => 'ဘင်္ဂါလီ',
        'Bopo' => 'ဘိုပို',
        'Brah' => 'ဗွဟ်မမီ',
        'Brai' => 'ဘရေ',
        'Cyrl' => 'စစ်ရိလစ်',
        'Deva' => 'ဒီဗနာဂရီ',
        'Ethi' => 'အီသီယိုးပီးယား',
        'Geor' => 'ဂျော်ဂျီယာ',
        'Grek' => 'ဂရိ',
        'Gujr' => 'ဂုဂျာရသီ',
        'Guru' => 'ဂူရူ',
        'Hanb' => 'ဟန်ဘ်',
        'Hang' => 'ဟန်ဂူးလ်',
        'Hani' => 'ဟန်',
        'Hans' => 'ရိုးရှင်း',
        'Hant' => 'ရိုးရာ',
        'Hebr' => 'ဟီဗရူး',
        'Hira' => 'ဟီရဂန',
        'Hrkt' => 'ဂျပန် အက္ခရာ',
        'Jamo' => 'ဂျမို',
        'Java' => 'ဂျာဗားနီးစ်',
        'Jpan' => 'ဂျပန်',
        'Kali' => 'ကယားလီ',
        'Kana' => 'ခတခန',
        'Khmr' => 'ခမာ',
        'Knda' => 'ခန်နာဒါ',
        'Kore' => 'ကိုရီးယား',
        'Laoo' => 'လာအို',
        'Latn' => 'လက်တင်',
        'Mlym' => 'မလေယာလမ်',
        'Mong' => 'မွန်ဂိုလီးယား',
        'Mymr' => 'မြန်မာ',
        'Orya' => 'အိုရာ',
        'Sinh' => 'ဆင်ဟာလ',
        'Tale' => 'တိုင်လီ',
        'Taml' => 'တမီးလ်',
        'Telu' => 'တီလု',
        'Tglg' => 'တဂလော့ဂ်',
        'Thaa' => 'သာအ်',
        'Thai' => 'ထိုင်း',
        'Tibt' => 'တိဘက်',
        'Visp' => 'မြင်နိုင်သော စကား',
        'Xpeo' => 'ပါရှန် အဟောင်း',
        'Yiii' => 'ရီ',
        'Zmth' => 'ဂဏန်းသင်္ချာ',
        'Zsye' => 'အီမိုဂျီ',
        'Zsym' => 'သင်္ကေတ',
        'Zxxx' => 'ထုံးတမ်းသဖွယ်လိုက်နာလျက်ရှိသော',
        'Zyyy' => 'အများနှင့်သက်ဆိုင်သော',
    ],
];

==> symfony_8.0.6+dfsg.orig.tar.xz: symfony-8.0.6/src/Symfony/Component/Intl/Resources/data/scripts/my.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'အက်ဒ်လမ်',
        'Arab' => 'အာရေဗျ',
        'Aran' => 'နက်စ်တာလိခ်',
        'Armn' => 'အာမေးနီးယား',
        'Beng' => 'ဘင်္ဂါလီ',
        'Bopo' => 'ဘိုပို',
        'Brah' => 'ဗွဟ်မမီ',
        'Brai' => 'ဘရေ',
        'Cakm' => 'ချပ်ခ်မာ',
        'Cans' => 'ကင်န်စ်',
        'Cher' => 'ချာရိုကီး',
        'Cyrl' => 'စစ်ရိလစ်',
        'Deva' => 'ဒီဗနာဂရီ',
        'Ethi' => 'အီသီယိုးပီးယား',
        'Geor' => 'ဂျော်ဂျီယာ',
        'Grek' => 'ဂရိ',
        'Gujr' => 'ဂုဂျာရသီ',
        'Guru' => 'ဂူရူ',
        'Hanb' => 'ဟန်ဘ်',
        'Hang' => 'ဟန်ဂူးလ်',
        'Hani' => 'ဟန်',
        'Hans' => 'ရိုးရှင်း',
        'Hant' => 'ရိုးရာ',
        'Hebr' => 'ဟီဗရူး',
        'Hira' => 'ဟီရဂန',
        'Hrkt' => 'ဂျပန် အက္ခရာ',
        'Jamo' => 'ဂျမို',
        'Java' => 'ဂျာဗားနီးစ်',
        'Jpan' => 'ဂျပန်',
        'Kali' => 'ကယားလီ',
        'Kana' => 'ခတခန',
        'Khmr' => 'ခမာ',
        'Knda' => 'ခန်နာဒါ',
        'Kore' => 'ကိုရီးယား',
        'Laoo' => 'လာအို',
        'Latn' => 'လက်တင်',
        'Mlym' => 'မလေယာလမ်',
        'Mong' => 'မွန်ဂိုလီးယား',
        'Mtei' => 'မေတဲမာယက်',
        'Mymr' => 'မြန်မာ',
        'Nkoo' => 'အွန်ကို',
        'Olck' => 'အိုလ်ချီကီ',
        'Orya' => 'အိုရာ',
        'Rohg' => 'ဟာနီဖီ',
        'Sinh' => 'ဆင်ဟာလ',
        'Sund' => 'ဆူဒန်',
        'Syrc' => 'ဆီရီရက်ခ်',
        'Tale' => 'တိုင်လီ',
        'Taml' => 'တမီးလ်',
        'Telu' => 'တယ်လူဂူ',
        'Tfng' => 'တီဖီနော',
        'Tglg' => 'တဂလော့ဂ်',
        'Thaa' => 'သာအ်',
        'Thai' => 'ထိုင်း',
        'Tibt' => 'တိဘက်',
        'Vaii' => 'ဗိုင်း',
        'Visp' => 'မြင်နိုင်သော စကား',
        'Xpeo' => 'ပါရှန် အဟောင်း',
        'Yiii' => 'ရီ',
        'Zmth' => 'ဂဏန်းသင်္ချာ',
        'Zsye' => 'အီမိုဂျီ',
        'Zsym' => 'သင်္ကေတ',
        'Zxxx' => 'ထုံးတမ်းသဖွယ်လိုက်နာလျက်ရှိသော',
        'Zyyy' => 'အများနှင့်သက်ဆိုင်သော',
    ],
];
